import { WidgetTracker } from '@jupyterlab/apputils';
import { Signal } from '@lumino/signaling';
import { requestAPI } from './handler';
export class AppTracker extends WidgetTracker {
    constructor(options, appName) {
        super(options);
        this._runningInstances = [];
        this._widgetDisposed = new Signal(this);
        this._instanceChanged = new Signal(this);
        this._appName = appName;
    }
    async add(widget) {
        widget.disposed.connect(async () => {
            this._widgetDisposed.emit(widget);
            await this.updateRunningInstance();
        });
        super.add(widget);
        await this.updateRunningInstance();
    }
    get widgetDisposed() {
        return this._widgetDisposed;
    }
    get instanceChanged() {
        return this._instanceChanged;
    }
    set runningInstance(value) {
        this._runningInstances = value;
    }
    get runningInstance() {
        return this._runningInstances;
    }
    async updateRunningInstance() {
        if (this._appName === 'JupyterLite') {
            return;
        }
        this._runningInstances = await requestAPI({
            method: 'POST',
            body: JSON.stringify({
                method: 'request_running_app'
            })
        });
        this._instanceChanged.emit();
    }
}
