import { NotebookPanel } from '@jupyterlab/notebook';
export class NotebookFactory {
    constructor(options) {
        this.options = options;
    }
    async create(config, args) {
        var _a, _b;
        if (!config.sourceCode) {
            return;
        }
        const { documentManager, fileBrowser } = this.options;
        let found = false;
        let index = 0;
        let newName = config.title;
        const allFiles = new Set([...fileBrowser.model.items()].map(it => it.name));
        while (!found) {
            newName = `${config.title}${index === 0 ? '' : '-' + index}.ipynb`;
            if (!allFiles.has(newName)) {
                found = true;
            }
            else {
                index += 1;
            }
        }
        const fileBlob = new File([config.sourceCode], newName);
        await fileBrowser.model.upload(fileBlob);
        const configArgs = (_a = config.args) !== null && _a !== void 0 ? _a : {};
        const factory = (_b = configArgs['widget-type']) !== null && _b !== void 0 ? _b : 'default';
        const newPath = `${fileBrowser.model.path}/${newName}`;
        const doc = await documentManager.openOrReveal(newPath, factory);
        if (!doc) {
            console.error(`Failed to create widget with ${factory} factory`);
            return;
        }
        await doc.context.ready;
        doc.context.model.fromString(config.sourceCode);
        await doc.context.save();
        if (doc instanceof NotebookPanel) {
            await doc.sessionContext.ready;
            doc.content.activeCellIndex = 1;
        }
    }
}
