import { ICellModel } from '@jupyterlab/cells';
import { IEditorMimeTypeService, IEditorServices } from '@jupyterlab/codeeditor';
import { Context } from '@jupyterlab/docregistry';
import * as nbformat from '@jupyterlab/nbformat';
import { CellList, INotebookModel, INotebookTracker, NotebookPanel, StaticNotebook } from '@jupyterlab/notebook';
import { SimplifiedOutputArea } from '@jupyterlab/outputarea';
import { IRenderMimeRegistry } from '@jupyterlab/rendermime';
import { ServiceManager } from '@jupyterlab/services';
import { IExecuteReplyMsg } from '@jupyterlab/services/lib/kernel/messages';
import { IAppModel } from '../../token';
import { GridStackItem } from './item';
export declare const VIEW = "grid_default";
export declare class AppModel implements IAppModel {
    private options;
    constructor(options: AppModel.IOptions);
    /**
     * Whether the handler is disposed.
     */
    get isDisposed(): boolean;
    dispose(): void;
    get notebook(): nbformat.INotebookContent;
    get rendermime(): IRenderMimeRegistry;
    get cells(): CellList | undefined;
    get context(): Context<INotebookModel> | undefined;
    get panel(): NotebookPanel | undefined;
    initialize(): Promise<void>;
    private _getCellInfo;
    createCell(cellModel: ICellModel): GridStackItem;
    executeCell(cell: ICellModel, output: SimplifiedOutputArea): Promise<IExecuteReplyMsg | undefined>;
    private _notebook;
    private _notebookPanel?;
    private _context?;
    private _isDisposed;
}
export declare namespace AppModel {
    interface IOptions {
        notebook: nbformat.INotebookContent;
        manager: ServiceManager.IManager;
        rendermime: IRenderMimeRegistry;
        tracker: INotebookTracker;
        contentFactory: NotebookPanel.IContentFactory;
        mimeTypeService: IEditorMimeTypeService;
        editorConfig: StaticNotebook.IEditorConfig;
        notebookConfig: StaticNotebook.INotebookConfig;
        editorServices: IEditorServices;
    }
}
