import { NotebookModelFactory, NotebookPanel, Notebook } from '@jupyterlab/notebook';
import { UUID } from '@lumino/coreutils';
import { CustomContext } from './custom_context';
export async function createNotebookContext(options) {
    var _a, _b, _c;
    const factory = new NotebookModelFactory({
        disableDocumentWideUndoRedo: false
    });
    const manager = options.manager;
    const path = UUID.uuid4() + '.ipynb';
    await manager.ready;
    const context = new CustomContext({
        manager,
        factory,
        path,
        kernelPreference: {
            shouldStart: true,
            canStart: true,
            shutdownOnDispose: true,
            name: (_a = manager.kernelspecs.specs) === null || _a === void 0 ? void 0 : _a.default
        }
    });
    // await context.model.initialize();
    await context.sessionContext.initialize();
    await ((_c = (_b = context.sessionContext.session) === null || _b === void 0 ? void 0 : _b.kernel) === null || _c === void 0 ? void 0 : _c.info);
    return context;
}
export function createNotebook(options) {
    const { rendermime, editorServices } = options;
    const editorFactory = editorServices.factoryService.newInlineEditor;
    return new Notebook({
        rendermime,
        contentFactory: new Notebook.ContentFactory({ editorFactory }),
        mimeTypeService: editorServices.mimeTypeService
    });
}
export function createNotebookPanel(options) {
    const { context, rendermime, editorServices } = options;
    const content = createNotebook({ rendermime, editorServices });
    return new NotebookPanel({
        content,
        context
    });
}
