import { StaticNotebook } from '@jupyterlab/notebook';
import { UUID } from '@lumino/coreutils';
import { AppModel } from './app_model';
import { AppWidget } from './app_widget';
export class NotebookGridFactory {
    constructor(options) {
        this.options = options;
    }
    async create(config) {
        if (!config.sourceCode) {
            console.error('Notebook source is missing');
            return;
        }
        const notebook = JSON.parse(config.sourceCode);
        if (config.cwd) {
            const cwdCell = {
                cell_type: 'code',
                execution_count: null,
                id: UUID.uuid4(),
                metadata: {
                    extensions: {
                        jupyter_dashboards: {
                            activeView: 'grid_default',
                            views: {
                                grid_default: {
                                    col: null,
                                    height: 2,
                                    hidden: true,
                                    locked: true,
                                    row: null,
                                    width: 2
                                }
                            }
                        }
                    }
                },
                outputs: [],
                source: [
                    'import os\n',
                    'try:\n',
                    `  os.chdir('${config.cwd}')\n`,
                    'except:\n',
                    '  pass'
                ]
            };
            notebook.cells = [cwdCell, ...notebook.cells];
        }
        const model = new AppModel({
            notebook,
            manager: this.options.manager,
            rendermime: this.options.rendermime,
            tracker: this.options.tracker,
            contentFactory: this.options.contentFactory,
            mimeTypeService: this.options.mimeTypeService,
            editorConfig: StaticNotebook.defaultEditorConfig,
            notebookConfig: StaticNotebook.defaultNotebookConfig,
            editorServices: this.options.editorServices
        });
        const panel = new AppWidget({
            id: UUID.uuid4(),
            label: config.title,
            model
        });
        return { panel };
    }
}
