import { TerminalAPI } from '@jupyterlab/services';
import { Terminal } from '@jupyterlab/terminal';
export class TerminalFactory {
    constructor(options) {
        this.options = options;
    }
    async create(config, args) {
        var _a;
        const cmd = config.source;
        const name = config.title.replace(/\s+/g, '');
        const reuse = (_a = config.args) === null || _a === void 0 ? void 0 : _a.reuse;
        const cwd = config.cwd;
        const { themeManager, app } = this.options;
        const manager = app.serviceManager.terminals;
        const models = await TerminalAPI.listRunning();
        let session;
        const modelNames = models.map(d => d.name);
        if (reuse === true) {
            if (modelNames.includes(name)) {
                session = manager.connectTo({ model: { name } });
            }
            else {
                session = await manager.startNew({ name, cwd });
            }
        }
        else {
            let idx = 1;
            let newName = '';
            while (true) {
                newName = `${name}${idx}`;
                if (modelNames.includes(newName)) {
                    idx += 1;
                }
                else {
                    break;
                }
            }
            session = await manager.startNew({ name: newName, cwd });
        }
        const terminal = new Terminal(session, {
            initialCommand: cmd,
            theme: 'inherit'
        });
        terminal.title.closable = true;
        const themeCb = () => {
            terminal.setOption('theme', 'inherit');
        };
        themeManager === null || themeManager === void 0 ? void 0 : themeManager.themeChanged.connect(themeCb);
        terminal.disposed.connect(() => {
            themeManager === null || themeManager === void 0 ? void 0 : themeManager.themeChanged.disconnect(themeCb);
        });
        return { panel: terminal };
    }
}
