import { IFrame } from '@jupyterlab/apputils';
import { UUID } from '@lumino/coreutils';
import { requestAPI } from '../../handler';
export class URLFactory {
    async create(config, args) {
        const source = config.source;
        if (typeof source !== 'string') {
            return;
        }
        const instanceId = UUID.uuid4();
        const options = {};
        if (config.args) {
            const sandbox = config.args['sandbox'];
            const referrerPolicy = config.args['referrerPolicy'];
            const createNewWindow = config.args['createNewWindow'];
            if (createNewWindow) {
                window.open(source, '_blank');
                return;
            }
            if (sandbox) {
                options['sandbox'] = sandbox;
            }
            if (referrerPolicy) {
                options['referrerPolicy'] = referrerPolicy;
            }
        }
        const widget = new IFrame(options);
        widget.title.label = config.title;
        widget.title.closable = true;
        widget.disposed.connect(async () => {
            await requestAPI({
                method: 'POST',
                body: JSON.stringify({
                    method: 'terminate_resources',
                    id: config.id,
                    instanceId
                })
            });
        });
        widget.url = source;
        return { panel: widget };
    }
}
